@@ -306,9 +306,18 @@ class PerfTB:
 
         # Save and open plot
         if save_path:
-            fig.write_image(save_path, engine="kaleido")
+            export_success = False
+            try:
+                fig.write_image(save_path, engine="kaleido")
+                export_success = True
             # pprint(f"Saved: {os.path.abspath(save_path)}")
-            if open_plot and os.name == "nt":  # Windows
+            except Exception as e:
+                print(f"Error saving plot: {e}")
+                pprint(
+                    "Failed to save plot. Check this link: https://stackoverflow.com/questions/69016568/unable-to-export-plotly-images-to-png-with-kaleido. Maybe you need to downgrade kaleido version to 0.1.* or install it via pip install kaleido==0.1.*"
+                )
+                return
+            if export_success and open_plot and os.name == "nt":  # Windows
                 os.system(f'start "" "{os.path.abspath(save_path)}"')
         return fig
 
